@@ -36,10 +36,14 @@ choices_cluster_tool = ['usearch', 'vsearch', 'cd-hit-est']
 default_cluster_tool = 'usearch'
 default_cluster_exec = default_usearch_exec
 default_cluster_ident = 0.9
+default_length_ratio = 0.0
 default_cluster_prefix=''
 map_cluster_tool = {'cd-hit-est': runCDHit,
                     'usearch': runUClust,
                     'vsearch': runUClust}
+min_cluster_ident = {'cd-hit-est': 0.80,
+                     'usearch': 0.0,
+                     'vsearch': 0.0}
 
 def processQueue(alive, data_queue, result_queue,
                  cluster_func, cluster_args={},
@@ -129,7 +133,8 @@ def processQueue(alive, data_queue, result_queue,
     return None
 
 
-def clusterSets(seq_file, ident=default_cluster_ident, seq_start=0, seq_end=None, set_field=default_barcode_field,
+def clusterSets(seq_file, ident=default_cluster_ident, length_ratio=default_length_ratio,
+                seq_start=0, seq_end=None, set_field=default_barcode_field,
                 cluster_field=default_cluster_field, cluster_prefix=default_cluster_prefix,
                 cluster_tool=default_cluster_tool, cluster_exec=default_cluster_exec,
                 out_file=None, out_args=default_out_args, nproc=None, queue_size=None):
@@ -139,6 +144,7 @@ def clusterSets(seq_file, ident=default_cluster_ident, seq_start=0, seq_end=None
     Arguments:
       seq_file : the sample sequence file name.
       ident : the identity threshold for clustering sequences.
+      length_ratio : minimum short/long length ratio allowed within a cluster.
       seq_start : the start position to trim sequences at before clustering.
       seq_end : the end position to trim sequences at before clustering.
       set_field : the annotation containing set IDs.
@@ -178,9 +184,14 @@ def clusterSets(seq_file, ident=default_cluster_ident, seq_start=0, seq_end=None
     except:
         printError('Invalid clustering tool %s.' % cluster_tool)
 
+    # Check the minimum identity
+    if ident < min_cluster_ident[cluster_tool]:
+        printError('Minimum identity %s too low for clustering tool %s.' % (str(ident), cluster_tool))
+
     # Define cluster function parameters
     cluster_args = {'cluster_exec': cluster_exec,
                     'ident': ident,
+                    'length_ratio': length_ratio,
                     'seq_start': seq_start,
                     'seq_end': seq_end}
 
@@ -220,7 +231,8 @@ def clusterSets(seq_file, ident=default_cluster_ident, seq_start=0, seq_end=None
     return result['out_files']
 
 
-def clusterAll(seq_file, ident=default_cluster_ident, seq_start=0, seq_end=None,
+def clusterAll(seq_file, ident=default_cluster_ident, length_ratio=default_length_ratio,
+               seq_start=0, seq_end=None,
                cluster_field=default_cluster_field, cluster_prefix=default_cluster_prefix,
                cluster_tool=default_cluster_tool, cluster_exec=default_cluster_exec,
                out_file=None, out_args=default_out_args, nproc=None):
@@ -230,6 +242,7 @@ def clusterAll(seq_file, ident=default_cluster_ident, seq_start=0, seq_end=None,
     Arguments:
       seq_file : the sample sequence file name.
       ident : the identity threshold for clustering sequences.
+      length_ratio : minimum short/long length ratio allowed within a cluster.
       seq_start : the start position to trim sequences at before clustering.
       seq_end : the end position to trim sequences at before clustering.
       cluster_field : the name of the output cluster field.
@@ -274,6 +287,10 @@ def clusterAll(seq_file, ident=default_cluster_ident, seq_start=0, seq_end=None,
     except:
         printError('Invalid clustering tool %s.' % cluster_tool)
 
+    # Check the minimum identity
+    if ident < min_cluster_ident[cluster_tool]:
+        printError('Minimum identity %s too low for clustering tool %s.' % (str(ident), cluster_tool))
+
     # Count sequence file and parse into a list of SeqRecords
     result_count = countSeqFile(seq_file)
     seq_iter = readSeqFile(seq_file)
@@ -281,7 +298,7 @@ def clusterAll(seq_file, ident=default_cluster_ident, seq_start=0, seq_end=None,
     # Perform clustering
     start_time = time()
     printMessage('Running %s' % cluster_tool, start_time=start_time, width=25)
-    cluster_dict = cluster_func(seq_iter, ident=ident,
+    cluster_dict = cluster_func(seq_iter, ident=ident, length_ratio=length_ratio,
                                 seq_start=seq_start, seq_end=seq_end,
                                 threads=nproc, cluster_exec=cluster_exec)
     printMessage('Done', start_time=start_time, end=True, width=25)
@@ -336,9 +353,9 @@ def clusterAll(seq_file, ident=default_cluster_ident, seq_start=0, seq_end=None,
     return pass_handle.name
 
 
-def clusterBarcodes(seq_file, ident=default_cluster_ident,
-                    barcode_field=default_barcode_field,
-                    cluster_field=default_cluster_field, cluster_prefix=default_cluster_prefix,
+def clusterBarcodes(seq_file, ident=default_cluster_ident, length_ratio=default_length_ratio,
+                    barcode_field=default_barcode_field, cluster_field=default_cluster_field,
+                    cluster_prefix=default_cluster_prefix,
                     cluster_tool=default_cluster_tool, cluster_exec=default_cluster_exec,
                     out_file=None, out_args=default_out_args, nproc=None):
     """
@@ -347,6 +364,7 @@ def clusterBarcodes(seq_file, ident=default_cluster_ident,
     Arguments:
       seq_file : the sample sequence file name.
       ident : the identity threshold for clustering sequences.
+      length_ratio : minimum short/long length ratio allowed within a cluster.
       barcode_field : the annotation field containing barcode sequences.
       cluster_field : the name of the output cluster field.
       cluster_prefix : string defining a prefix for the cluster identifier.
@@ -360,7 +378,7 @@ def clusterBarcodes(seq_file, ident=default_cluster_ident,
               if None defaults to the number of CPUs.
 
     Returns:
-      str : the clustered output file name
+      str: the clustered output file name
     """
     # Function to modify SeqRecord header with cluster identifier
     def _header(seq, cluster, field=cluster_field, prefix=cluster_prefix,
@@ -396,6 +414,10 @@ def clusterBarcodes(seq_file, ident=default_cluster_ident,
     except:
         printError('Invalid clustering tool %s.' % cluster_tool)
 
+    # Check the minimum identity
+    if ident < min_cluster_ident[cluster_tool]:
+        printError('Minimum identity %s too low for clustering tool %s.' % (str(ident), cluster_tool))
+
     # Count sequence file and parse into a list of SeqRecords
     result_count = countSeqFile(seq_file)
     barcode_iter = (_barcode(x) for x in readSeqFile(seq_file))
@@ -403,7 +425,8 @@ def clusterBarcodes(seq_file, ident=default_cluster_ident,
     # Perform clustering
     start_time = time()
     printMessage('Running %s' % cluster_tool, start_time=start_time, width=25)
-    cluster_dict = cluster_func(barcode_iter, ident=ident, seq_start=0, seq_end=None,
+    cluster_dict = cluster_func(barcode_iter, ident=ident, length_ratio=length_ratio,
+                                seq_start=0, seq_end=None,
                                 threads=nproc, cluster_exec=cluster_exec)
     printMessage('Done', start_time=start_time, end=True, width=25)
 
@@ -484,15 +507,15 @@ def getArgParser():
                             formatter_class=CommonHelpFormatter, add_help=False)
     group_help = parser.add_argument_group('help')
     group_help.add_argument('--version', action='version',
-                            version='%(prog)s:' + ' %s-%s' %(__version__, __date__))
+                            version='%(prog)s:' + ' %s %s' %(__version__, __date__))
     group_help.add_argument('-h', '--help', action='help', help='show this help message and exit')
     subparsers = parser.add_subparsers(title='subcommands', dest='command', metavar='',
                                        help='Clustering method')
     # TODO:  This is a temporary fix for Python issue 9253
     subparsers.required = True
 
-    # Parent parser
-    parent_parser = getCommonArgParser(multiproc=True)
+    # Parent parser of common arguments
+    parent_parser = ArgumentParser(formatter_class=CommonHelpFormatter, add_help=False)
     group_parent = parent_parser.add_argument_group('common clustering arguments')
     group_parent.add_argument('-k', action='store', dest='cluster_field', type=str,
                               default=default_cluster_field,
@@ -503,6 +526,12 @@ def getArgParser():
                               help='''The sequence identity threshold to use for clustering. 
                                    Note, how identity is calculated is specific to the clustering 
                                    application used.''')
+    group_parent.add_argument('--length', action='store', dest='length_ratio', type=float,
+                              default=default_length_ratio,
+                              help='''The minimum allowed shorter/longer sequence length ratio allowed 
+                                   within a cluster. Setting this value to 1.0 will require identical 
+                                   length matches within clusters. A value of 0.0 will allow clusters
+                                   containing any length of substring.''')
     group_parent.add_argument('--prefix', action='store', dest='cluster_prefix', type=str,
                               default=default_cluster_prefix,
                                help='''A string to use as the prefix for each cluster identifier.
@@ -510,12 +539,14 @@ def getArgParser():
     group_parent.add_argument('--cluster', action='store', dest='cluster_tool',
                               choices=choices_cluster_tool, default=default_cluster_tool,
                               help='''The clustering tool to use for assigning clusters. 
-                                   Must be one of usearch, vsearch or cd-hit-est.''')
+                                   Must be one of usearch, vsearch or cd-hit-est. Note, for 
+                                   cd-hit-est the maximum memory limit is set to 3GB.''')
     group_parent.add_argument('--exec', action='store', dest='cluster_exec', default=None,
                               help='The name or path of the usearch, vsearch or cd-hit-est executable.')
 
     # Sequence set clustering arguments
-    parser_set = subparsers.add_parser('set', parents=[parent_parser],
+    parser_set = subparsers.add_parser('set',
+                                       parents=[getCommonArgParser(log=True, multiproc=True), parent_parser],
                                        formatter_class=CommonHelpFormatter, add_help=False,
                                        help='Cluster sequences within annotation sets.',
                                        description='Cluster sequences within annotation sets.')
@@ -533,7 +564,8 @@ def getArgParser():
     parser_set.set_defaults(func=clusterSets)
 
     # Total sequence clustering arguments
-    parser_all = subparsers.add_parser('all', parents=[parent_parser],
+    parser_all = subparsers.add_parser('all',
+                                       parents=[getCommonArgParser(log=False, failed=False, multiproc=True), parent_parser],
                                        formatter_class=CommonHelpFormatter, add_help=False,
                                        help='Cluster all sequences regardless of annotation.',
                                        description='Cluster all sequences regardless of annotation.')
@@ -547,7 +579,8 @@ def getArgParser():
     parser_all.set_defaults(func=clusterAll)
 
     # Sequence set clustering arguments
-    parser_barcode = subparsers.add_parser('barcode', parents=[parent_parser],
+    parser_barcode = subparsers.add_parser('barcode',
+                                           parents=[getCommonArgParser(log=False, failed=False, multiproc=True), parent_parser],
                                            formatter_class=CommonHelpFormatter, add_help=False,
                                            help='Cluster reads by clustering barcode sequences.',
                                            description='Cluster reads by clustering barcode sequences.')
